server/sources/rql2sql.py
branchstable
changeset 8238 087bb529035c
parent 7902 2ada3052e626
child 8245 d53762ae5961
--- a/server/sources/rql2sql.py	Mon Feb 13 17:57:07 2012 +0100
+++ b/server/sources/rql2sql.py	Thu Feb 16 14:14:52 2012 +0100
@@ -339,7 +339,7 @@
     * `outer_chains`, list of list of strings. Each list represent a tables
       that have to be outer joined together.
 
     * `outer_tables`, dictionnary used as index of tables used in outer join ::
 
         'table alias': (outertype, [conditions], [chain])
 
@@ -721,7 +721,7 @@
         self.attr_map = attrmap
 
     def generate(self, union, args=None, varmap=None):
         """return SQL queries and a variable dictionnary from a RQL syntax tree
 
         :partrqls: a list of couple (rqlst, solutions)
         :args: optional dictionary with values of substitutions used in the query
@@ -772,11 +772,11 @@
         return '\nUNION ALL\n'.join(sqls)
 
     def select_sql(self, select, needalias=False):
         """return SQL queries and a variable dictionnary from a RQL syntax tree
 
         :select: a selection statement of the syntax tree (`rql.stmts.Select`)
-        :solution: a dictionnary containing variables binding.
-          A solution's dictionnary has variable's names as key and variable's
+        :solution: a dictionary containing variables binding.
+          A solution's dictionary has variable's names as key and variable's
           types as values
         :needwrap: boolean telling if the query will be wrapped in an outer
           query (to deal with aggregat and/or grouping)
@@ -339,7 +339,7 @@
       that have to be outer joined together.
 
-    * `outer_tables`, dictionnary used as index of tables used in outer join ::
+    * `outer_tables`, dictionary used as index of tables used in outer join ::
 
         'table alias': (outertype, [conditions], [chain])
@@ -721,7 +721,7 @@
 
     def generate(self, union, args=None, varmap=None):
-        """return SQL queries and a variable dictionnary from a RQL syntax tree
+        """return SQL queries and a variable dictionary from a RQL syntax tree
 
         :partrqls: a list of couple (rqlst, solutions)
@@ -772,11 +772,11 @@
 
     def select_sql(self, select, needalias=False):
-        """return SQL queries and a variable dictionnary from a RQL syntax tree
+        """return SQL queries and a variable dictionary from a RQL syntax tree
 
         :select: a selection statement of the syntax tree (`rql.stmts.Select`)